var NAVTREEINDEX12 =
{
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset__all.html":[7,0,0,199],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__master__get__context.html":[8,0,0,200],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__master__get__context.html":[7,0,0,200],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__max__priority__is__set.html":[8,0,0,201],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__max__priority__is__set.html":[7,0,0,201],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__min__priority__is__set.html":[8,0,0,202],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__min__priority__is__set.html":[7,0,0,202],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__move__task__to__ctx.html":[8,0,0,203],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__move__task__to__ctx.html":[7,0,0,203],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__overlapping__ctxs__on__worker.html":[8,0,0,204],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__overlapping__ctxs__on__worker.html":[7,0,0,204],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__register__close__callback.html":[7,0,0,205],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__register__close__callback.html":[8,0,0,205],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__remove__workers.html":[7,0,0,206],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__remove__workers.html":[8,0,0,206],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__revert__task__counters.html":[8,0,0,207],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__revert__task__counters.html":[7,0,0,207],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__context.html":[8,0,0,208],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__context.html":[7,0,0,208],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__inheritor.html":[7,0,0,209],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__inheritor.html":[8,0,0,209],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__max__priority.html":[8,0,0,210],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__max__priority.html":[7,0,0,210],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__min__priority.html":[8,0,0,211],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__min__priority.html":[7,0,0,211],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__policy__data.html":[8,0,0,212],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__policy__data.html":[7,0,0,212],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__stop__task__submission.html":[7,0,0,213],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__stop__task__submission.html":[8,0,0,213],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__unbook__workers__for__task.html":[8,0,0,214],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__unbook__workers__for__task.html":[7,0,0,214],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__get__id.html":[7,0,0,215],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__get__id.html":[8,0,0,215],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__is__master__for__child__ctx.html":[8,0,0,216],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__is__master__for__child__ctx.html":[7,0,0,216],
"interfacefstarpu__mod_1_1fstarpu__sched__get__max__priority.html":[7,0,0,217],
"interfacefstarpu__mod_1_1fstarpu__sched__get__max__priority.html":[8,0,0,217],
"interfacefstarpu__mod_1_1fstarpu__sched__get__min__priority.html":[7,0,0,218],
"interfacefstarpu__mod_1_1fstarpu__sched__get__min__priority.html":[8,0,0,218],
"interfacefstarpu__mod_1_1fstarpu__sched__set__max__priority.html":[7,0,0,219],
"interfacefstarpu__mod_1_1fstarpu__sched__set__max__priority.html":[8,0,0,219],
"interfacefstarpu__mod_1_1fstarpu__sched__set__min__priority.html":[7,0,0,220],
"interfacefstarpu__mod_1_1fstarpu__sched__set__min__priority.html":[8,0,0,220],
"interfacefstarpu__mod_1_1fstarpu__shutdown.html":[7,0,0,221],
"interfacefstarpu__mod_1_1fstarpu__shutdown.html":[8,0,0,221],
"interfacefstarpu__mod_1_1fstarpu__sleep.html":[7,0,0,222],
"interfacefstarpu__mod_1_1fstarpu__sleep.html":[8,0,0,222],
"interfacefstarpu__mod_1_1fstarpu__tag__declare__deps__array.html":[8,0,0,223],
"interfacefstarpu__mod_1_1fstarpu__tag__declare__deps__array.html":[7,0,0,223],
"interfacefstarpu__mod_1_1fstarpu__tag__get__task.html":[8,0,0,224],
"interfacefstarpu__mod_1_1fstarpu__tag__get__task.html":[7,0,0,224],
"interfacefstarpu__mod_1_1fstarpu__tag__notify__from__apps.html":[8,0,0,225],
"interfacefstarpu__mod_1_1fstarpu__tag__notify__from__apps.html":[7,0,0,225],
"interfacefstarpu__mod_1_1fstarpu__tag__remove.html":[8,0,0,226],
"interfacefstarpu__mod_1_1fstarpu__tag__remove.html":[7,0,0,226],
"interfacefstarpu__mod_1_1fstarpu__tag__restart.html":[8,0,0,227],
"interfacefstarpu__mod_1_1fstarpu__tag__restart.html":[7,0,0,227],
"interfacefstarpu__mod_1_1fstarpu__tag__wait.html":[8,0,0,228],
"interfacefstarpu__mod_1_1fstarpu__tag__wait.html":[7,0,0,228],
"interfacefstarpu__mod_1_1fstarpu__tag__wait__array.html":[8,0,0,229],
"interfacefstarpu__mod_1_1fstarpu__tag__wait__array.html":[7,0,0,229],
"interfacefstarpu__mod_1_1fstarpu__task__clean.html":[7,0,0,230],
"interfacefstarpu__mod_1_1fstarpu__task__clean.html":[8,0,0,230],
"interfacefstarpu__mod_1_1fstarpu__task__create.html":[7,0,0,231],
"interfacefstarpu__mod_1_1fstarpu__task__create.html":[8,0,0,231],
"interfacefstarpu__mod_1_1fstarpu__task__create__sync.html":[7,0,0,232],
"interfacefstarpu__mod_1_1fstarpu__task__create__sync.html":[8,0,0,232],
"interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html":[8,0,0,233],
"interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html":[7,0,0,233],
"interfacefstarpu__mod_1_1fstarpu__task__declare__deps__array.html":[8,0,0,234],
"interfacefstarpu__mod_1_1fstarpu__task__declare__deps__array.html":[7,0,0,234],
"interfacefstarpu__mod_1_1fstarpu__task__destroy.html":[7,0,0,235],
"interfacefstarpu__mod_1_1fstarpu__task__destroy.html":[8,0,0,235],
"interfacefstarpu__mod_1_1fstarpu__task__dup.html":[8,0,0,236],
"interfacefstarpu__mod_1_1fstarpu__task__dup.html":[7,0,0,236],
"interfacefstarpu__mod_1_1fstarpu__task__end__dep__add.html":[7,0,0,237],
"interfacefstarpu__mod_1_1fstarpu__task__end__dep__add.html":[8,0,0,237],
"interfacefstarpu__mod_1_1fstarpu__task__end__dep__release.html":[8,0,0,238],
"interfacefstarpu__mod_1_1fstarpu__task__end__dep__release.html":[7,0,0,238],
"interfacefstarpu__mod_1_1fstarpu__task__finished.html":[7,0,0,239],
"interfacefstarpu__mod_1_1fstarpu__task__finished.html":[8,0,0,239],
"interfacefstarpu__mod_1_1fstarpu__task__get__current.html":[8,0,0,240],
"interfacefstarpu__mod_1_1fstarpu__task__get__current.html":[7,0,0,240],
"interfacefstarpu__mod_1_1fstarpu__task__get__implementation.html":[7,0,0,241],
"interfacefstarpu__mod_1_1fstarpu__task__get__implementation.html":[8,0,0,241],
"interfacefstarpu__mod_1_1fstarpu__task__init.html":[7,0,0,242],
"interfacefstarpu__mod_1_1fstarpu__task__init.html":[8,0,0,242],
"interfacefstarpu__mod_1_1fstarpu__task__insert.html":[8,0,0,243],
"interfacefstarpu__mod_1_1fstarpu__task__insert.html":[7,0,0,243],
"interfacefstarpu__mod_1_1fstarpu__task__nready.html":[7,0,0,244],
"interfacefstarpu__mod_1_1fstarpu__task__nready.html":[8,0,0,244],
"interfacefstarpu__mod_1_1fstarpu__task__nsubmitted.html":[7,0,0,245],
"interfacefstarpu__mod_1_1fstarpu__task__nsubmitted.html":[8,0,0,245],
"interfacefstarpu__mod_1_1fstarpu__task__set__destroy.html":[7,0,0,246],
"interfacefstarpu__mod_1_1fstarpu__task__set__destroy.html":[8,0,0,246],
"interfacefstarpu__mod_1_1fstarpu__task__set__implementation.html":[7,0,0,247],
"interfacefstarpu__mod_1_1fstarpu__task__set__implementation.html":[8,0,0,247],
"interfacefstarpu__mod_1_1fstarpu__task__submit.html":[7,0,0,248],
"interfacefstarpu__mod_1_1fstarpu__task__submit.html":[8,0,0,248],
"interfacefstarpu__mod_1_1fstarpu__task__submit__to__ctx.html":[7,0,0,249],
"interfacefstarpu__mod_1_1fstarpu__task__submit__to__ctx.html":[8,0,0,249],
"interfacefstarpu__mod_1_1fstarpu__task__wait.html":[8,0,0,250],
"interfacefstarpu__mod_1_1fstarpu__task__wait.html":[7,0,0,250],
"interfacefstarpu__mod_1_1fstarpu__task__wait__array.html":[8,0,0,251],
"interfacefstarpu__mod_1_1fstarpu__task__wait__array.html":[7,0,0,251],
"interfacefstarpu__mod_1_1fstarpu__task__wait__for__all.html":[8,0,0,252],
"interfacefstarpu__mod_1_1fstarpu__task__wait__for__all.html":[7,0,0,252],
"interfacefstarpu__mod_1_1fstarpu__task__wait__for__all__in__ctx.html":[8,0,0,253],
"interfacefstarpu__mod_1_1fstarpu__task__wait__for__all__in__ctx.html":[7,0,0,253],
"interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted.html":[8,0,0,254],
"interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted.html":[7,0,0,254],
"interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted__in__ctx.html":[8,0,0,255],
"interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted__in__ctx.html":[7,0,0,255],
"interfacefstarpu__mod_1_1fstarpu__task__wait__for__no__ready.html":[8,0,0,256],
"interfacefstarpu__mod_1_1fstarpu__task__wait__for__no__ready.html":[7,0,0,256],
"interfacefstarpu__mod_1_1fstarpu__tensor__data__register.html":[8,0,0,257],
"interfacefstarpu__mod_1_1fstarpu__tensor__data__register.html":[7,0,0,257],
"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldt.html":[7,0,0,258],
"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldt.html":[8,0,0,258],
"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldy.html":[7,0,0,259],
"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldy.html":[8,0,0,259],
"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldz.html":[7,0,0,260],
"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldz.html":[8,0,0,260],
"interfacefstarpu__mod_1_1fstarpu__tensor__get__nt.html":[7,0,0,261],
"interfacefstarpu__mod_1_1fstarpu__tensor__get__nt.html":[8,0,0,261],
"interfacefstarpu__mod_1_1fstarpu__tensor__get__nx.html":[7,0,0,262],
"interfacefstarpu__mod_1_1fstarpu__tensor__get__nx.html":[8,0,0,262],
"interfacefstarpu__mod_1_1fstarpu__tensor__get__ny.html":[8,0,0,263],
"interfacefstarpu__mod_1_1fstarpu__tensor__get__ny.html":[7,0,0,263],
"interfacefstarpu__mod_1_1fstarpu__tensor__get__nz.html":[7,0,0,264],
"interfacefstarpu__mod_1_1fstarpu__tensor__get__nz.html":[8,0,0,264],
"interfacefstarpu__mod_1_1fstarpu__tensor__get__ptr.html":[8,0,0,265],
"interfacefstarpu__mod_1_1fstarpu__tensor__get__ptr.html":[7,0,0,265],
"interfacefstarpu__mod_1_1fstarpu__tensor__ptr__register.html":[8,0,0,266],
"interfacefstarpu__mod_1_1fstarpu__tensor__ptr__register.html":[7,0,0,266],
"interfacefstarpu__mod_1_1fstarpu__timing__now.html":[7,0,0,267],
"interfacefstarpu__mod_1_1fstarpu__timing__now.html":[8,0,0,267],
"interfacefstarpu__mod_1_1fstarpu__topology__print.html":[7,0,0,268],
"interfacefstarpu__mod_1_1fstarpu__topology__print.html":[8,0,0,268],
"interfacefstarpu__mod_1_1fstarpu__trace__user__event.html":[7,0,0,269],
"interfacefstarpu__mod_1_1fstarpu__trace__user__event.html":[8,0,0,269],
"interfacefstarpu__mod_1_1fstarpu__unpack__arg.html":[7,0,0,270],
"interfacefstarpu__mod_1_1fstarpu__unpack__arg.html":[8,0,0,270],
"interfacefstarpu__mod_1_1fstarpu__usleep.html":[7,0,0,271],
"interfacefstarpu__mod_1_1fstarpu__usleep.html":[8,0,0,271],
"interfacefstarpu__mod_1_1fstarpu__variable__data__register.html":[7,0,0,272],
"interfacefstarpu__mod_1_1fstarpu__variable__data__register.html":[8,0,0,272],
"interfacefstarpu__mod_1_1fstarpu__variable__get__ptr.html":[7,0,0,273],
"interfacefstarpu__mod_1_1fstarpu__variable__get__ptr.html":[8,0,0,273],
"interfacefstarpu__mod_1_1fstarpu__variable__ptr__register.html":[8,0,0,274],
"interfacefstarpu__mod_1_1fstarpu__variable__ptr__register.html":[7,0,0,274],
"interfacefstarpu__mod_1_1fstarpu__vector__data__register.html":[8,0,0,275],
"interfacefstarpu__mod_1_1fstarpu__vector__data__register.html":[7,0,0,275],
"interfacefstarpu__mod_1_1fstarpu__vector__divide__in__2.html":[7,0,0,276],
"interfacefstarpu__mod_1_1fstarpu__vector__divide__in__2.html":[8,0,0,276],
"interfacefstarpu__mod_1_1fstarpu__vector__filter__block.html":[8,0,0,277],
"interfacefstarpu__mod_1_1fstarpu__vector__filter__block.html":[7,0,0,277],
"interfacefstarpu__mod_1_1fstarpu__vector__filter__block__shadow.html":[8,0,0,278],
"interfacefstarpu__mod_1_1fstarpu__vector__filter__block__shadow.html":[7,0,0,278],
"interfacefstarpu__mod_1_1fstarpu__vector__filter__list.html":[8,0,0,279],
"interfacefstarpu__mod_1_1fstarpu__vector__filter__list.html":[7,0,0,279],
"interfacefstarpu__mod_1_1fstarpu__vector__filter__list__long.html":[7,0,0,280],
"interfacefstarpu__mod_1_1fstarpu__vector__filter__list__long.html":[8,0,0,280],
"interfacefstarpu__mod_1_1fstarpu__vector__get__nx.html":[8,0,0,281],
"interfacefstarpu__mod_1_1fstarpu__vector__get__nx.html":[7,0,0,281],
"interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html":[7,0,0,282],
"interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html":[8,0,0,282],
"interfacefstarpu__mod_1_1fstarpu__vector__ptr__register.html":[7,0,0,283],
"interfacefstarpu__mod_1_1fstarpu__vector__ptr__register.html":[8,0,0,283],
"interfacefstarpu__mod_1_1fstarpu__void__data__register.html":[7,0,0,284],
"interfacefstarpu__mod_1_1fstarpu__void__data__register.html":[8,0,0,284],
"interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html":[7,0,0,285],
"interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html":[8,0,0,285],
"interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[7,0,0,286],
"interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[8,0,0,286],
"interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[7,0,0,287],
"interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[8,0,0,287],
"interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[7,0,0,288],
"interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[8,0,0,288],
"interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[7,0,0,289],
"interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[8,0,0,289],
"interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[7,0,0,290],
"interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[8,0,0,290],
"interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[7,0,0,291],
"interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[8,0,0,291],
"interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[8,0,0,292],
"interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[7,0,0,292],
"interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[8,0,0,293],
"interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[7,0,0,293],
"interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[7,0,0,294],
"interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[8,0,0,294],
"interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[8,0,0,295],
"interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[7,0,0,295],
"interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html":[8,0,0,296],
"interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html":[7,0,0,296],
"interfacefstarpu__mod_1_1fstarpu__worker__is__blocked.html":[8,0,0,297],
"interfacefstarpu__mod_1_1fstarpu__worker__is__blocked.html":[7,0,0,297],
"interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[8,0,0,298],
"interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[7,0,0,298],
"interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[7,0,0,299],
"interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[8,0,0,299],
"interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[7,0,0,300],
"interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[8,0,0,300],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__barrier.html":[8,0,1,0],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__cache__flush.html":[8,0,1,1],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__cache__flush__all__data.html":[8,0,1,2],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__cache__is__enabled.html":[8,0,1,3],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__cache__set.html":[8,0,1,4],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__comm__rank.html":[8,0,1,5],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__comm__size.html":[8,0,1,6],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__comm__stats__disable.html":[8,0,1,7],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__comm__stats__enable.html":[8,0,1,8],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__comm__stats__retrieve.html":[8,0,1,9],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__data__get__rank.html":[8,0,1,10],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__data__get__tag.html":[8,0,1,11],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__data__migrate.html":[8,0,1,12],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__data__register.html":[8,0,1,13],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__data__register__comm.html":[8,0,1,14],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__data__selection__get__current__policy.html":[8,0,1,15],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__data__selection__set__current__policy.html":[8,0,1,16],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__data__set__rank.html":[8,0,1,17],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__data__set__rank__comm.html":[8,0,1,18],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__data__set__tag.html":[8,0,1,19],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__datatype__register.html":[8,0,1,20],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__datatype__unregister.html":[8,0,1,21],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__gather__detached.html":[8,0,1,22],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__get__communication__tag.html":[8,0,1,23],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__get__data__on__node.html":[8,0,1,24],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__get__data__on__node__detached.html":[8,0,1,25],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__insert__task.html":[8,0,1,26],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__irecv.html":[8,0,1,27],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__isend.html":[8,0,1,28],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__isend__array__detached__unlock__tag.html":[8,0,1,29],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__isend__array__detached__unlock__tag__prio.html":[8,0,1,30],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__isend__detached.html":[8,0,1,31],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__isend__detached__prio.html":[8,0,1,32],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__isend__detached__unlock__tag.html":[8,0,1,33],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__isend__detached__unlock__tag__prio.html":[8,0,1,34],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__isend__prio.html":[8,0,1,35],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__issend.html":[8,0,1,36],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__issend__detached.html":[8,0,1,37],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__issend__detached__prio.html":[8,0,1,38],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__issend__prio.html":[8,0,1,39],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__node__selection__register__policy.html":[8,0,1,40],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__node__selection__unregister__policy.html":[8,0,1,41],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__recv.html":[8,0,1,42],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__recv__array__detached__unlock__tag.html":[8,0,1,43],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__recv__detached.html":[8,0,1,44],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__recv__detached__sequential__consistency.html":[8,0,1,45],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__recv__detached__unlock__tag.html":[8,0,1,46]
};
